@@ -3,7 +3,7 @@ require "spec_helper"
 describe 'FastGettext::TranslationRepository::Mo' do
   before do
     @rep = FastGettext::TranslationRepository.build('test',:path=>File.join('spec', 'locale'))
-    @rep.is_a?(FastGettext::TranslationRepository::Mo).should be_true
+    @rep.is_a?(FastGettext::TranslationRepository::Mo).should == true
   end
 
   it "can be built" do
@@ -20,6 +20,29 @@ describe 'FastGettext::TranslationRepository::Mo' do
     @rep.plural('Axis','Axis').should == ['Achse','Achsen']
   end
 
+  describe :reload do
+    before do
+      mo_file = FastGettext::MoFile.new('spec/locale/de/LC_MESSAGES/test2.mo')
+
+      FastGettext::MoFile.stub(:new).and_return(FastGettext::MoFile.empty)
+      FastGettext::MoFile.stub(:new).with('spec/locale/de/LC_MESSAGES/test.mo').and_return(mo_file)
+    end
+
+    it "can reload" do
+      FastGettext.locale = 'de'
+
+      @rep['Untranslated and translated in test2'].should be_nil
+
+      @rep.reload
+
+      @rep['Untranslated and translated in test2'].should == 'Translated'
+    end
+
+    it "returns true" do
+      @rep.reload.should == true
+    end
+  end
+
   it "has access to the mo repositories pluralisation rule" do
     FastGettext.locale = 'en'
     rep = FastGettext::TranslationRepository.build('plural_test',:path=>File.join('spec','locale'))
@@ -28,6 +51,8 @@ describe 'FastGettext::TranslationRepository::Mo' do
   end
 
   it "can work in SAFE mode" do
-    `ruby spec/cases/safe_mode_can_handle_locales.rb 2>&1`.should == 'true'
+    pending_if RUBY_VERSION > "2.0" do
+      `ruby spec/cases/safe_mode_can_handle_locales.rb 2>&1`.should == 'true'
+    end
   end
 end
